==> Acme-MetaSyntactic-Themes-1.000.tar.gz: Acme-MetaSyntactic-Themes-1.000/lib/Acme/MetaSyntactic/pynchon.pm <==
package Acme::MetaSyntactic::pynchon;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pynchon - The Pynchon theme

=head1 DESCRIPTION

Character names from Thomas Pynchon's books.

David Landgren not only named all the machines in the C<mongueurs.net>
domain (C<stencil>, C<sferics> and C<profane>) after characters from
Thomas Pynchon's books, but also provided a first list.

The pynchon list will probably grow in future versions, as David goes
through his books.

=head1 CONTRIBUTOR

David Landgren.

Introduced in Acme-MetaSyntactic version 0.03, published on January 14, 2005.

Updated by David Landgren in version 0.41, published on September 26, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
porpentine slothrop stencil profane godolphin yoyodyne waste
sferics oedipa mondaugen eigenvalue schlozhauer schoenmaker
bongo_shaftsbury maijstral achtfaden sachsa mantissa angevine
anthroresearch apocheir aquilina barkhausen basilisco bergomask beukes
bodine boeblich bondelschwaartz borracho carruthers_pillow chiclitz chobb
contango covess delgado dnubietna dupiro echerze eckstine fairing falange
fauchard fazzo fenice flake fleische foppl gadrulfi gascoigne gebrail
gerfaut geronimo girgis gland gonzi goodfellow gottschalk groomsman
halidom katz khevenhuller_metsch kholsky knoop lazar lepsius leutwein
lowenstein manganese mannaro

==> Acme-MetaSyntactic-Themes-1.056.tar.gz: Acme-MetaSyntactic-Themes-1.056/lib/Acme/MetaSyntactic/pynchon.pm <==
package Acme::MetaSyntactic::pynchon;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pynchon - The Pynchon theme

=head1 DESCRIPTION

Character names from Thomas Pynchon's books.

David Landgren not only named all the machines in the C<mongueurs.net>
domain (C<stencil>, C<sferics> and C<profane>) after characters from
Thomas Pynchon's books, but also provided a first list.

The pynchon list will probably grow in future versions, as David goes
through his books.

=head1 CONTRIBUTOR

David Landgren.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=item *

2005-09-26

Updated by David Landgren in Acme-MetaSyntactic version 0.41.

=item *

2005-01-14

Introduced in Acme-MetaSyntactic version 0.03.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
porpentine slothrop stencil profane godolphin yoyodyne waste
sferics oedipa mondaugen eigenvalue schlozhauer schoenmaker
bongo_shaftsbury maijstral achtfaden sachsa mantissa angevine
anthroresearch apocheir aquilina barkhausen basilisco bergomask beukes
bodine boeblich bondelschwaartz borracho carruthers_pillow chiclitz chobb
contango covess delgado dnubietna dupiro echerze eckstine fairing falange
fauchard fazzo fenice flake fleische foppl gadrulfi gascoigne gebrail
gerfaut geronimo girgis gland gonzi goodfellow gottschalk groomsman
halidom katz khevenhuller_metsch kholsky knoop lazar lepsius leutwein
lowenstein manganese mannaro
